@@ -19,6 +19,7 @@ import getpass
 import hashlib
 import logging
 import os
+import platform
 import time
 import webbrowser
 
@@ -28,6 +29,13 @@ import yaml
 
 
 class Tools(object):
+    @staticmethod
+    def get_home_path()->str:
+        if "Windows" in platform.system():
+            return os.environ["USERPROFILE"]
+        else:
+            return os.environ["HOME"]
+
     @staticmethod
     def getvalue(dict,item):
         if dict.get(item,"") == "":
